==> fts-1.3.zip: fts/src/org/logical_paradox/fts/FTSBtreeKey.java <==
/**
 * LOGICAL-PARADOX.ORG
 * Copyright (C)2004 satoshi akabane(akabane@logical-paradox.org)
 *
 */
package org.logical_paradox.fts;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import org.logical_paradox.common.btree.BtreeException;
import org.logical_paradox.common.btree.BtreeKey;

/**
 * FTŜ߂̃L[NX
 * @author satoshi akabane@logical-paradox.org
 */
public class FTSBtreeKey extends BtreeKey {
	// L[̃oCgTCY
	public static final int KEY_BYTE_SIZE = 8 + 8;		// eĂL[̒ + VRM̃ItZbg

	private String _key;
	private long _offset;

	/**
	 * RXgN^
	 * @param o IuWFNg
	 * @throws BtreeException L[̕Ɏs
	 */
	public FTSBtreeKey(Object o) throws BtreeException {
		super(o);
	}
	/**
	 * RXgN^
	 * @param bstream L[̃oCg
	 * @throws BtreeException oCg񂩂̕Ɏs
	 */
	public FTSBtreeKey(byte[] bstream) throws BtreeException {
		super(bstream);
	}
	
	/**
	 * IuWFNgL[𕜌
	 * @param o IuWFNg
	 */
	protected void objectToBtreeKey(Object o) throws BtreeException {
		_key = ((String)o).trim();
	}

	/**
	 * oCg񂩂L[𕜌
	 * @param bstream L[̃oCg\
	 */
	protected void byteStreamToBtreeKey(byte[] bstream) throws BtreeException {
		ByteBuffer buffer = ByteBuffer.allocate(bstream.length).order(ByteOrder.BIG_ENDIAN);
		buffer.put(bstream);
		buffer.rewind();

		_offset = buffer.getLong();
		byte[] strbuf = new byte[bstream.length - 8];
		buffer.get(strbuf);
		_key = new String(strbuf).trim();
	}

	/**
	 * L[̕\Ԃ
	 * @return \ꂽL[
	 */
	public String toString() {
		return _key.toString();
	}

	/**
	 * L[̒lǂԂ
	 * @return true; / false:Ⴄ
	 */
	public boolean equals(Object obj) {
		if(obj instanceof String) {
			String s = (String)obj;
			return _key.equals(s.trim());
		} else if(obj instanceof BtreeKey) {
			String s = ((BtreeKey)obj).toString().trim();
			return _key.equals(s);
		} else {
			return false;
		}
	}
	/**
	 * VRM̃oCgψʂݒ肷
	 * @param offset oCgψ
	 */
	public void setOffset(long offset) {
		_offset = offset;
	}
	/**
	 * VRM̃oCgψʂԂ
	 * @return oCgψ
	 */
	public long getOffset() {
		return _offset;
	}
	/**
	 * w肳ꂽL[菬ǂԂ
	 * @param key rΏ
	 * @return boolean true: this < key / false: this >= key
	 */
	public boolean isLessThan( BtreeKey key ) {
		return _key.compareTo(key.toString().trim()) < 0;
	}

	/**
	 * w肳ꂽL[傫ǂԂ
	 * @param key rΏ
	 * @return boolean true: this > key / false: this <= key
	 */
	public boolean isGreaterThan( BtreeKey key ) {
		return _key.compareTo(key.toString().trim()) > 0;
	}

	/**
	 * L[̃oCg\Ԃ
	 * @return oCg
	 */
	public byte[] byteStream() {
		ByteBuffer buffer = ByteBuffer.allocate(FTSBtreeKey.KEY_BYTE_SIZE).order(ByteOrder.BIG_ENDIAN);
		buffer.putLong(_offset);
		buffer.put(_key.getBytes());
		
		return buffer.array();
	}

	/**
	 * ̃L[̃oCgTCYԂ
	 * @return oCgTCY
	 */
	public int byteSize() {
		return KEY_BYTE_SIZE;
	}
}

==> fts-1.6.zip: fts/src/org/logical_paradox/fts/FTSBtreeKey.java <==
/**
 * LOGICAL-PARADOX.ORG
 * Copyright (C)2004 satoshi akabane(akabane@logical-paradox.org)
 *
 */
package org.logical_paradox.fts;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import org.logical_paradox.common.btree.BtreeException;
import org.logical_paradox.common.btree.BtreeKey;

/**
 * FTŜ߂̃L[NX
 * @author satoshi akabane@logical-paradox.org
 */
public class FTSBtreeKey extends BtreeKey {
	// L[̃oCgTCY
	public static final int KEY_BYTE_SIZE = 8 + 8;		// eĂL[̒ + VRM̃ItZbg

	private String _key;
	private long _offset;

	/**
	 * RXgN^
	 * @param o IuWFNg
	 * @throws BtreeException L[̕Ɏs
	 */
	public FTSBtreeKey(Object o) throws BtreeException {
		super(o);
	}
	/**
	 * RXgN^
	 * @param bstream L[̃oCg
	 * @throws BtreeException oCg񂩂̕Ɏs
	 */
	public FTSBtreeKey(byte[] bstream) throws BtreeException {
		super(bstream);
	}
	
	/**
	 * IuWFNgL[𕜌
	 * @param o IuWFNg
	 */
	protected void objectToBtreeKey(Object o) throws BtreeException {
		_key = ((String)o).trim();
	}

	/**
	 * oCg񂩂L[𕜌
	 * @param bstream L[̃oCg\
	 */
	protected void byteStreamToBtreeKey(byte[] bstream) throws BtreeException {
//		ByteBuffer buffer = ByteBuffer.allocate(bstream.length).order(ByteOrder.BIG_ENDIAN);
//		buffer.put(bstream, 0, 8);	//put(bstream);
//		buffer.rewind();

		_offset =
				((long)bstream[7] & 0xff) | 
				(long)(bstream[6] & 0xff) << 8 |
				(long)(bstream[5] & 0xff) << 16 |
				(long)(bstream[4] & 0xff) << 24 |
				(long)(bstream[3] & 0xff) << 32 |
				(long)(bstream[2] & 0xff) << 40 |
				(long)(bstream[1] & 0xff) << 48 |
				(long)(bstream[0] & 0xff) << 56;
//if(_offset != 0) {
//	System.out.println("offset=" + _offset);
//}
//		_offset = buffer.getLong();
//		byte[] strbuf = new byte[bstream.length - 8];
//		buffer.get(strbuf);
//		_key = new String(strbuf).trim();
		_key = new String(bstream, 8, bstream.length - 8).trim();
	}

	/**
	 * L[̕\Ԃ
	 * @return \ꂽL[
	 */
	public String toString() {
		return _key.toString();
	}

	/**
	 * L[̒lǂԂ
	 * @return true; / false:Ⴄ
	 */
	public boolean equals(Object obj) {
		if(obj instanceof String) {
			String s = (String)obj;
			return _key.equals(s.trim());
		} else if(obj instanceof BtreeKey) {
			String s = ((BtreeKey)obj).toString().trim();
			return _key.equals(s);
		} else {
			return false;
		}
	}
	/**
	 * VRM̃oCgψʂݒ肷
	 * @param offset oCgψ
	 */
	public void setOffset(long offset) {
		_offset = offset;
	}
	/**
	 * VRM̃oCgψʂԂ
	 * @return oCgψ
	 */
	public long getOffset() {
		return _offset;
	}
	/**
	 * w肳ꂽL[菬ǂԂ
	 * @param key rΏ
	 * @return boolean true: this < key / false: this >= key
	 */
	public boolean isLessThan( BtreeKey key ) {
		return _key.compareTo(key.toString().trim()) < 0;
	}

	/**
	 * w肳ꂽL[傫ǂԂ
	 * @param key rΏ
	 * @return boolean true: this > key / false: this <= key
	 */
	public boolean isGreaterThan( BtreeKey key ) {
		return _key.compareTo(key.toString().trim()) > 0;
	}

	/**
	 * L[̃oCg\Ԃ
	 * @return oCg
	 */
	public byte[] byteStream() {
		ByteBuffer buffer = ByteBuffer.allocate(FTSBtreeKey.KEY_BYTE_SIZE).order(ByteOrder.BIG_ENDIAN);
		buffer.putLong(_offset);
		buffer.put(_key.getBytes());
		
		return buffer.array();
	}

	/**
	 * ̃L[̃oCgTCYԂ
	 * @return oCgTCY
	 */
	public int byteSize() {
		return KEY_BYTE_SIZE;
	}
}
